export class Session {
  createdAt: Date
  authenticated: boolean
  hasExpired (): boolean
}

export { WebSocket } from './ws/index'

/**
  Request and response types.

  These vary per route type but are all built on the base of
  Polka’s request and response objects which are, themselves,
  based on the incoming message and server response types of
  Node’s own http module.
*/

import type { IncomingMessage, ServerResponse } from 'http'

export interface ParsedURL {
	pathname: string
	search: string
	query: Record<string, string | string[]> | void
	raw: string
}

export type PolkaResponse = ServerResponse

export interface PolkaRequest extends IncomingMessage {
	url: string
	method: string
	originalUrl: string
	params: Record<string, string>
	path: string
	search: string
	query: Record<string,string>
	body?: any
	_decoded?: true
	_parsedUrl: ParsedURL
}

export interface KittenRequest extends PolkaRequest {
  is (types:Array<string>|string):string|false|null
  session:Session
}

export interface KittenResponse extends PolkaResponse {
  get (location:string):void
  redirect (location:string):void
  permanentRedirect (location:string):void
  badRequest (body?:string):void
  unauthenticated (body?:string):void
  forbidden (body?:string):void
  notFound (body?:string):void
  error (body?:string):void
}

export interface KittenPostRequest extends KittenRequest {
  uploads: Upload[]
}
